@@ -25,6 +25,7 @@
 #include <gtk/gtk.h>
 
 #include "gs-box.h"
+#include "gs-cleanup.h"
 
 typedef struct {
 	GtkWidget       *widget;
@@ -128,11 +129,12 @@ gs_box_get_preferred_width (GtkWidget *widget, gint *min, gint *nat)
 {
 	GsBox *box = GS_BOX (widget);
 	GsBoxChild *child;
-	gint cm, *cn;
+	gint cm;
 	gint n_children;
 	gint ms, m, n;
 	GList *l;
 	gint i;
+	_cleanup_free_ gint *cn = NULL;
 
 	n_children = g_list_length (box->children);
 
@@ -152,8 +154,6 @@ gs_box_get_preferred_width (GtkWidget *widget, gint *min, gint *nat)
 		n += MAX (cn[i], cm);
 	}
 
-	g_free (cn);
-
 	if (min)
 		*min = m;
 	if (nat)
