@@ -29,7 +29,6 @@
 
 #include "gs-app.h"
 #include "gs-category.h"
-#include "gs-cleanup.h"
 #include "gs-profile.h"
 
 G_BEGIN_DECLS
@@ -181,6 +180,16 @@ gboolean	 gs_plugin_add_search			(GsPlugin	*plugin,
 							 GList		**list,
 							 GCancellable	*cancellable,
 							 GError		**error);
+gboolean	 gs_plugin_add_search_files		(GsPlugin	*plugin,
+							 gchar		**values,
+							 GList		**list,
+							 GCancellable	*cancellable,
+							 GError		**error);
+gboolean	 gs_plugin_add_search_what_provides	(GsPlugin	*plugin,
+							 gchar		**values,
+							 GList		**list,
+							 GCancellable	*cancellable,
+							 GError		**error);
 const gchar	**gs_plugin_get_deps			(GsPlugin	*plugin);
 gboolean	 gs_plugin_add_installed		(GsPlugin	*plugin,
 							 GList		**list,
